module.exports = defineTest({
	description: 'preserves class names even if the class is renamed'
});
